@@ -1,7 +1,7 @@
 #! /usr/bin/perl -w
 
 use strict;
-use POSIX;
+use POSIX qw/SIGHUP/;
 use IO::Socket::INET;
 use Event::Lib;
 
@@ -30,7 +30,7 @@ sub handle_client {
 	if (/^quit$/) {
 	    # this client says goodbye
 	    close $h;
-	    $e->free;
+	    $e->del;
 	    last;
 	}
     }
